(global-set-key "\M-g"  'goto-line)       ; ESC-g goto Line
(global-set-key "\C-cm" 'compile)         ; Compile

(set-face-font 'default '"-adobe-times-medium-r-normal-*-*-140-*-*-p-*-iso10646-1")

;; Backup files/versioning
(setq make-backup-files nil)             ; don't make backup files
(setq version-control 'never)            ; don't use version numbers for backup files
(setq backup-by-copying-when-linked t)   ; do not destroy hardlinks
(setq bkup-backup-directory-info '((t "~/.backups/" ok-create full-path)))

(setq version-control 'preserve-prefer-numbered)
(setq-default delete-old-versions t)

(delete-selection-mode 1)                 ; selected text will be replaced if you start to type

(setq inhibit-startup-message t)          ; surpress annoying startup message

;(setq-default tab-width 8)               ; tab = 4 spaces
(setq-default indent-tabs-mode nil)       ; use spaces (not tabs) for indenting
;;(setq kill-ring-max 10)                 ; don't save too many kills
(setq require-final-newline nil)          ; terminate last line in file with newline
(setq default-truncate-lines t)           ;; If default-truncate-lines is non-nil truncate lines
;;(setq default-major-mode 'text-mode)    ; default mode is text mode
(setq next-screen-context-lines 1)        ; # of lines of overlap when scrolling

;;(mwheel-install) ;; Scrollrad
(setq-default scroll-step 1)              ; scroll by one line

(setq auto-save-interval 300)             ; autosave every N characters typed
(setq scroll-preserve-screen-position t)  ; make pgup/dn remember current line
(setq next-line-add-newlines nil)         ; don't scroll past end of file
(global-auto-revert-mode 1)               ; autorevert buffers if files change

;; line break / truncate
(setq default-fill-column 77)             ; the column beyond which do word wrap
;;(require 'longlines)

;; (autoload 'php-mode "php-mode.el" "PHP mode" t)
(autoload 'longlines-mode "longlines.el" "Minor mode for automatically wrapping long lines." t)
(setq-default longlines-wrap-follows-window-size t)
;;(setq-default longlines-auto-wrap t)
;;(setq-default longlines-mode t)

(show-paren-mode t)                       ; highlight matching parens, etc
(setq show-paren-style 'expression)       ; highlight character, not expression

(setq column-number-mode t)               ; show colum number
(setq line-number-mode t)                 ; show line  number

(setq minibuffer-max-depth nil)

(autoload 'boxquote "boxquote.el" "Lustige Kaesten" t)
(require 'boxquote nil t) ;; Zitierkästen

(autoload 'thinks   "thinks.el" "Denkblasen" t)
(require  'thinks   nil t)   ;; .oO()Oo.
(require  'message  nil t)  ;; addons like rot13 (message-caesar-)
(mwheel-install)    ;; Scrollrad
(footnote-mode t)   ;; Fussnoten
;;(require  'doxymacs nil t) ;; Versteht c++ Kommentar im Javadocstyl (doxygen)

;;(add-hook 'c-mode-common-hook 'doxymacs-mode)

(add-hook 'text-mode-hook '(lambda () (flyspell-mode) (setq ispell-dictionary   "german-new8"))) ;; Turn on Flyspell mode automatically in some modes and related modes.
(add-hook 'mail-mode-hook '(lambda () (flyspell-mode) (setq ispell-dictionary   "german-new8"))) ;; Turn on Flyspell mode automatically in mail mode.
(add-hook 'mail-mode-hook 'turn-on-auto-fill)           ;; auto-fill-mode in email mode

;; Change ispelll dictionary depending on the filename
(setq-default ispell-dictionary   "de_DE-neu")
(setq ispell-dictionary           "de_DE-neu")
(setq ispell-local-dictionary     "de_DE-neu")
(setq flyspell-default-dictionary "de_DE-neu")

(setq-default ispell-program-name "aspell")    ;; aspell statt ispell
;(setq-default ispell-program-name "/tmp/my_aspell.sh")    ;; aspell statt ispell


(add-hook 'find-file-hooks (function (lambda ()
      (if (string-match "\\.txt$"         buffer-file-name) (ispell-change-dictionary "de_DE-neu"))
      (if (string-match "\\.de\\.txt$"    buffer-file-name) (ispell-change-dictionary "de_DE-neu"))
      (if (string-match "\\.en\\.txt$"    buffer-file-name) (ispell-change-dictionary "en_GB"))
      (if (string-match "dm_remod\\.tex$" buffer-file-name) (ispell-change-dictionary "en_GB"))
)))

;;
;; File associations
;;
;; Make Text mode the default mode for new buffers.
(setq default-major-mode 'text-mode)
(setq auto-mode-alist (cons '("\\.txt$" . text-mode) auto-mode-alist))
(setq auto-mode-alist (cons '("mutt"             . mail-mode)      auto-mode-alist))
(setq auto-mode-alist (cons '("\\.html$"         . html-mode)      auto-mode-alist))
(setq auto-mode-alist (cons '("\\.htm$"          . html-mode)      auto-mode-alist))
(setq auto-mode-alist (cons '("\\.xml$"          . nxml-mode)       auto-mode-alist))
(setq auto-mode-alist (cons '("\\.c$"            . c++-mode)       auto-mode-alist))
(setq auto-mode-alist (cons '("\\.mkf$"          . makefile-mode)  auto-mode-alist))
(setq auto-mode-alist (cons '("\\.tex$"          . latex-mode)     auto-mode-alist))
(setq auto-mode-alist (cons '("\\.php$"          . php-mode)       auto-mode-alist))
(setq auto-mode-alist (cons '("svn-commit\\.tmp" . flyspell-mode)  auto-mode-alist)) ;; flyspell *aus*schalten

(add-hook 'latex-mode-hook
          '(lambda ()
             (longlines-mode)
           )
)

(prefer-coding-system 'utf-8)
;(modify-coding-system-alist 'file "\\.utf8$" 'utf-8)

(custom-set-variables
  ;; custom-set-variables was added by Custom.
  ;; If you edit it by hand, you could mess it up, so be careful.
  ;; Your init file should contain only one such instance.
  ;; If there is more than one, they won't work right.
 '(ange-ftp-try-passive-mode t)
 '(case-fold-search t)
 '(column-number-mode t)
 '(global-font-lock-mode t nil (font-lock))
 '(ps-landscape-mode t)
 '(show-paren-mode t nil (paren))
 '(transient-mark-mode t))

(setq sgml-auto-activate-dtd t)  ;; If non-nil, loading a sgml-file will automatically try to activate its DTD.


;; Command to validate xml Files
(setq-default sgml-validate-command "onsgmls -s -wxml /usr/share/sgml/declaration/xml.dcl")


;; Print via xpp
(setq lpr-command "xpp")

;; for some reason Emacs lacks delete-line, implementing it with the
;; source from kill-line is, however, trivial
(defun delete-line (&optional arg)
  (interactive "P")
  (delete-region (point)
                 (progn
                   (if arg
                       (forward-visible-line (prefix-numeric-value arg))
                     (if (eobp)
                         (signal 'end-of-buffer nil))
                     (if (or (looking-at "[ \t]*$") (and kill-whole-line (bolp)))
                         (forward-visible-line 1)
                       (end-of-visible-line)))
                   (point)))
)
(global-set-key (kbd "C-k") 'delete-line)


;; Trailing whitespaces
(setq show-trailing-whitespace t);; Meta-x delete-trailing-whitespace

;; abbrev mode
(read-abbrev-file abbrev-file-name t)
(setq dabbrev-case-replace nil)  ; Preserve case when expanding
(setq-default abbrev-mode t)


;; Unicode input with emacs -nw
(when (not window-system)
 (set-keyboard-coding-system locale-coding-system)
 (set-terminal-coding-system locale-coding-system)
)

;; no more beep
(setq visible-bell t)

;; fix Ubuntu bug https://bugs.launchpad.net/emacs-snapshot/+bug/1251176
(require 'iso-transl)
